#
# spec file for package perl-Curses
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Curses
Name:           perl-Curses
Version:        1.44
Release:        1.5
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Terminal screen handling and optimization
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/G/GI/GIRAFFED/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  ncurses5-devel
# MANUAL END

%description
'Curses' is the interface between Perl and your system's curses(3) library.
For descriptions on the usage of a given function, variable, or constant,
consult your system's documentation, as such information invariably varies
(:-) between different curses(3) libraries and operating systems. This
document describes the interface itself, and assumes that you already know
how your system's curses(3) library works.

%prep
%autosetup  -n %{cpan_name}-%{version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644
# MANUAL BEGIN
sed -i '1s| /usr//bin/perl|%{__perl}|' demo.form
sed -i '1s| /usr/bin/perl|%{__perl}|' demo* gdc testsyms
chmod +x makeConfig
# MANUAL END

%build
export CURSES_CFLAGS="-I/usr/include/ncurses5/ncursesw"
export CURSES_LDFLAGS="-L%{_libdir}/ncurses5 -lncursesw"
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}" PANELS MENUS FORMS
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc ChangeLog demo demo2 demo.form demo.menu demo.panel HISTORY MAINTENANCE README
%license Artistic Copying

%changelog
* Wed Mar  8 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.44
  see /usr/share/doc/packages/perl-Curses/ChangeLog
  New in 1.44 (Released March 07, 2023)
    Implement A_ITALIC
* Thu Dec  8 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.43
  see /usr/share/doc/packages/perl-Curses/ChangeLog
  New in 1.43 (Released December 08, 2022)
    Fix missing file introduced in 1.42 that prevents all builds from working.
  New in 1.42 (Released December 07, 2022)
    Add missing return type declarations so it works with modern C compilers.
    Fix build failure with newer compilers: test compiles to find Curses library
    capabilities fail because necessary header files are not included because
    C_PANELFUNCTION etc are not defined because the test compiles do not include
    CursesFun.h, which they can't because the test compiles are part of creating
    CursesFun.h.  Solution: put C_PANELFUNCTION, etc in new config.h.
    Rename test.syms program to testsyms, because it is a more conventional
    name format.
* Fri Aug 19 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.41
  see /usr/share/doc/packages/perl-Curses/ChangeLog
* Sat Aug 13 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.39
  see /usr/share/doc/packages/perl-Curses/HISTORY
  New in 1.39 (Released August 12, 2022)
    Add #include <stdbool.h> to top of Curses.c to fix a conflict between the
    Curses header files and Perl header files that causes a "loadable library
    and perl binaries are mismatched" / handshake key failure when you try to
    load the Perl module.
* Mon Aug  2 2021 Pedro Monreal <pmonreal@suse.com>
- Update to 1.38:
  * Fix compilation failure with some compilers, including AIX's
    because _XOPEN_SOURCE_EXTENDED was defined with null value.
* Wed Jun  9 2021 Pedro Monreal <pmonreal@suse.com>
- Build and link against ncurses version 5 to fix missing exported
  symbols [bsc#1119646]
* Wed Jun  9 2021 Pedro Monreal <pmonreal@suse.com>
- Build with support for MENUS, PANELS and FORMS
- Fix perl script interpreters
* Sun Oct 18 2020 Dirk Stoecker <opensuse@dstoecker.de>
- updated to 1.37
  see /usr/share/doc/packages/perl-Curses/HISTORY
  New in 1.37
    Fix printw for wide characters.
    Fix bug: wenclose() and mouse_trafo() treat an integer as a boolean.  The
    functional effect is they return true if they fail to do the window move (I
    don't understand this - there's some kind of window move that is part of
    every function).  False is better.
* Wed Sep 12 2018 pmonrealgonzalez@suse.com
- updated to 1.36 (Released August 14, 2016)
  Fix the GNU Hurd thing from 1.35 by including the hints file in the
  manifest.
  New in 1.35 (Released July 11, 2016)
  Added hints file for GNU Hurd ($OSNAME == 'gnu').  From Pino Toscano.
  New in 1.34 (Released April 2, 2016)
  Several bugs fixed in demo programs (which also function as the
  documentation) for forms and menus and comments added explaining need to
  keep Perl variables around to avoid invalid memory references.
  New in 1.33 (Released October 3, 2015)
  Package contains META files.
- Cleaned with spec-cleaner
* Fri Feb  6 2015 coolo@suse.com
- updated to 1.32
  Makefile.PL: if /usr/include/ncurses/ncurses.h exists, use Ncurses regardless
  of what the $guess_cfg table says for the OS at hand.  This fixes the former
  hybrid approach which didn't work for a Solaris 11 system that has both
  Ncurses and BSD curses.
  Typographical error in documentation fixed.
  New in 1.31 (Released April 26, 2014)
  Fix compile failure with some Curses libraries, introduced in
  1.29 - undefined KEY_CODE_YES.
  Fix documentation: wide character functions exist back to Perl 5.6,
  not 5.16.
  New in 1.30 (Released April 19, 2014)
  Fix build failure: Use older substitutes if Perl is too old to have
  the 'utf8_to_uvchr_buf' function they use; don't include the wide character
  functions if Perl is even too old to have the substitutes.  Broken in 1.29.
  Fix "constant not provided by your vendor" message when you refer to a
  function that does not exist in the Curses module.
  Minor fixes to documentation of new wide character functions.
  Fix warning about extra argument to c_setmevent .
  Fix documentation for "not defined in your Curses library" errors.
  (broken in 1.28).
  Fix demo programs' recognition of "not defined in your Curses library"
  errors (broken in 1.28).
  New in 1.29 (Released April 6, 2014)
  Add an alternate set of functions (getchar, ungetchar, getstring,
  instring, addstring, insstring) providing a more Perl-like interface,
  converting from and to Perl strings (instead of passing data to the C
  library verbatim) and using wide character functions if available in the
  underlying curses library.
  Written by Edgar Fu201337, Mathematisches Institut der Uni Bonn,
  <ef@math.uni-bonn.de>
* Fri Nov 18 2011 coolo@suse.com
- use original tar.gz
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Tue Feb  9 2010 coolo@novell.com
- update to 1.28
  * Disable Curses::Var::STORE.  It doesn't work (doesn't even compile) with
    newer Ncurses (due to updates to make Ncurses reentrant).  One can
    re-enable it by defining ALLOW_VARS_STORE in c-config.h.
  * Improve "not provided by your vendor" message.
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Feb 23 2009 anicka@suse.cz
- update to 1.27
  * Extraneous .i and .s files in 1.26 removed.  'make clean' cleans
  all .i and .s too.
  * 'gen' directory is replaced by gen.tar file, so CPAN doesn't
    index the stuff in there.  That directory is stuff for developing
    the Curses package, not stuff for users.
  * newterm() is available and putwin() and getwin() work in newer
  Perl (with PerlIO). We now use PerlIO_findFile().
* Wed Sep 10 2008 anicka@suse.cz
- update to 1.24
  * Export KEY_RESIZE, KEY_EVENT.
  * For Netbsd, allow both Netbsd and BSD guesses via CURSES_LIBTYPE,
  and default to Ncurses.
  * Add guess capability for Dragonfly.
* Mon Mar 10 2008 anicka@suse.cz
- update to 1.23
  * Fix crash of Makefile.PL on Windows.
  * Don't undefine 'bool' macro in c-darwin hints file.
  * Fix missing comment delimiter.
* Mon Nov 19 2007 anicka@suse.cz
- update to 1.19
- add -lpanel and -lmenu
  * Use Ncursesw (Ncurses with wide character functions) instead of
    Ncurses if available.
  * Change all sv_isa() to sv_derived_from() so you can use
    subclasses.
  * bugfixes, test fixes
* Thu Mar 29 2007 rguenther@suse.de
- add ncurses-devel BuildRequires
* Sat Mar 10 2007 mmarek@suse.cz
- link with ncursesw.so to make UTF8 output work
* Fri Jul 14 2006 anicka@suse.cz
- update to 1.14
  * Make demo.form work on 64 bit machine.
  * Add some narration to Makefile.PL to help with diagnosis.
  * Move undef of 'instr' from individual hint files to Curses.c
    and add explanation.
  * Some kind of build fix to get panels, forms, and menu functions
    to build.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Aug  1 2005 cthiel@suse.de
- update to version 1.12
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Tue Jul 15 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Tue May 20 2003 mjancar@suse.cz
- remove unpackaged files
* Fri Aug  9 2002 mls@suse.de
- use sv_isa instead of Perl_sv_isa for threaded perl
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Fri Aug  3 2001 rvasice@suse.cz
- update to version 1.06
- spec file cleanup
* Tue Nov 14 2000 cihlar@suse.cz
- clean up spec file
* Thu Nov  2 2000 grimmer@suse.de
- renamed from perl_cur to perl-Curses
- spec file cleanups
* Tue Aug 22 2000 cihlar@suse.cz
- update to version 1.05
- added BuildRoot
- bzipped sources
* Thu Jan 20 2000 ro@suse.de
- use macro for mandir
* Mon Nov  8 1999 choeger@suse.de
- first version
